@@ -16,6 +16,8 @@
  * and is licensed under the MIT license.
  */
 
+declare(strict_types=1);
+
 namespace ProxyManager\Proxy;
 
 /**
@@ -24,6 +26,6 @@ namespace ProxyManager\Proxy;
  * @author Marco Pivetta <ocramius@gmail.com>
  * @license MIT
  */
-interface GhostObjectInterface extends ProxyInterface
+interface GhostObjectInterface extends LazyLoadingInterface
 {
 }
